@@ -1,7 +1,13 @@
 """Vector-store based data structures."""
 
 from gpt_index.indices.vector_store.faiss import GPTFaissIndex
+from gpt_index.indices.vector_store.pinecone import GPTPineconeIndex
 from gpt_index.indices.vector_store.simple import GPTSimpleVectorIndex
 from gpt_index.indices.vector_store.weaviate import GPTWeaviateIndex
 
-__all__ = ["GPTFaissIndex", "GPTSimpleVectorIndex", "GPTWeaviateIndex"]
+__all__ = [
+    "GPTFaissIndex",
+    "GPTSimpleVectorIndex",
+    "GPTWeaviateIndex",
+    "GPTPineconeIndex",
+]
