@@ -1,4 +1,5 @@
 """Text splitter implementations."""
+from dataclasses import dataclass
 from typing import Callable, List, Optional
 
 from langchain.text_splitter import TextSplitter
@@ -6,6 +7,19 @@ from langchain.text_splitter import TextSplitter
 from gpt_index.utils import globals_helper
 
 
+@dataclass
+class TextSplit:
+    """Text split with overlap.
+
+    Attributes:
+        text_chunk: The text string.
+        num_char_overlap: The number of overlapping characters with the previous chunk.
+    """
+
+    text_chunk: str
+    num_char_overlap: int
+
+
 class TokenTextSplitter(TextSplitter):
     """Implementation of splitting text that looks at word tokens."""
 
@@ -89,10 +103,32 @@ class TokenTextSplitter(TextSplitter):
                 new_splits.extend(cur_splits2)
         return new_splits
 
-    def split_text(self, text: str) -> List[str]:
+    def split_text(self, text: str, extra_info_str: Optional[str] = None) -> List[str]:
         """Split incoming text and return chunks."""
+        text_slits = self.split_text_with_overlaps(text, extra_info_str=extra_info_str)
+        return [text_split.text_chunk for text_split in text_slits]
+
+    def split_text_with_overlaps(
+        self, text: str, extra_info_str: Optional[str] = None
+    ) -> List[TextSplit]:
+        """Split incoming text and return chunks with overlap size."""
         if text == "":
             return []
+
+        # NOTE: Consider extra info str that will be added to the chunk at query time
+        #       This reduces the effective chunk size that we can have
+        if extra_info_str is not None:
+            # NOTE: extra 2 newline chars for formatting when prepending in query
+            num_extra_tokens = len(self.tokenizer(f"{extra_info_str}\n\n")) + 1
+            effective_chunk_size = self._chunk_size - num_extra_tokens
+
+            if effective_chunk_size <= 0:
+                raise ValueError(
+                    "Effective chunk size is non positive after considering extra_info"
+                )
+        else:
+            effective_chunk_size = self._chunk_size
+
         # First we naively split the large input into a bunch of smaller ones.
         splits = text.split(self._separator)
         splits = self._process_splits(splits)
@@ -103,28 +139,40 @@ class TokenTextSplitter(TextSplitter):
         start_idx = 0
         cur_idx = 0
         cur_total = 0
+        prev_idx = 0  # store the previous end index
         while cur_idx < len(splits):
             cur_token = splits[cur_idx]
             num_cur_tokens = max(len(self.tokenizer(cur_token)), 1)
-            if num_cur_tokens > self._chunk_size:
+            if num_cur_tokens > effective_chunk_size:
                 raise ValueError(
                     "A single term is larger than the allowed chunk size.\n"
                     f"Term size: {num_cur_tokens}\n"
                     f"Chunk size: {self._chunk_size}"
+                    f"Effective chunk size: {effective_chunk_size}"
                 )
-
             # If adding token to current_doc would exceed the chunk size:
             # 1. First verify with tokenizer that current_doc
             # 1. Update the docs list
-            if cur_total + num_cur_tokens > self._chunk_size:
+            if cur_total + num_cur_tokens > effective_chunk_size:
                 # NOTE: since we use a proxy for counting tokens, we want to
                 # run tokenizer across all of current_doc first. If
                 # the chunk is too big, then we will reduce text in pieces
                 cur_idx = self._reduce_chunk_size(start_idx, cur_idx, splits)
-                docs.append(self._separator.join(splits[start_idx:cur_idx]))
+                overlap = 0
+                # after first round, check if last chunk ended after this chunk begins
+                if prev_idx > 0 and prev_idx > start_idx:
+                    overlap = sum([len(splits[i]) for i in range(start_idx, prev_idx)])
+                docs.append(
+                    TextSplit(self._separator.join(splits[start_idx:cur_idx]), overlap)
+                )
+                prev_idx = cur_idx
                 # 2. Shrink the current_doc (from the front) until it is gets smaller
                 # than the overlap size
-                while cur_total > self._chunk_overlap:
+                # NOTE: because counting tokens individually is an imperfect
+                # proxy (but much faster proxy) for the total number of tokens consumed,
+                # we need to enforce that start_idx <= cur_idx, otherwise
+                # start_idx has a chance of going out of bounds.
+                while cur_total > self._chunk_overlap and start_idx < cur_idx:
                     cur_num_tokens = max(len(self.tokenizer(splits[start_idx])), 1)
                     cur_total -= cur_num_tokens
                     start_idx += 1
@@ -138,7 +186,13 @@ class TokenTextSplitter(TextSplitter):
 
             cur_total += num_cur_tokens
             cur_idx += 1
-        docs.append(self._separator.join(splits[start_idx:cur_idx]))
+        overlap = 0
+        # after first round, check if last chunk ended after this chunk begins
+        if prev_idx > start_idx:
+            overlap = sum([len(splits[i]) for i in range(start_idx, prev_idx)]) + len(
+                range(start_idx, prev_idx)
+            )
+        docs.append(TextSplit(self._separator.join(splits[start_idx:cur_idx]), overlap))
         return docs
 
     def truncate_text(self, text: str) -> str:
