@@ -21,7 +21,7 @@ class WikipediaReader(BaseReader):
                 "`wikipedia` package not found, please run `pip install wikipedia`"
             )
 
-    def load_data(self, **load_kwargs: Any) -> List[Document]:
+    def load_data(self, pages: List[str], **load_kwargs: Any) -> List[Document]:
         """Load data from the input directory.
 
         Args:
@@ -30,12 +30,8 @@ class WikipediaReader(BaseReader):
         """
         import wikipedia
 
-        pages: List[str] = load_kwargs.pop("pages", None)
-        if pages is None:
-            raise ValueError('Must specify a "page" in `load_kwargs`.')
-
         results = []
         for page in pages:
-            page_content = wikipedia.page(page).content
+            page_content = wikipedia.page(page, **load_kwargs).content
             results.append(Document(page_content))
         return results
