@@ -1,6 +1,8 @@
 """Test recursive queries."""
 
-from typing import Any, Dict, List, Tuple
+from pathlib import Path
+from tempfile import TemporaryDirectory
+from typing import Any, Dict, List, Tuple, cast
 from unittest.mock import patch
 
 import pytest
@@ -221,6 +223,17 @@ def test_recursive_query_table_list(
     )
     assert str(response) == ("Test?:This is a test.")
 
+    # test serialize and then back
+    with TemporaryDirectory() as tmpdir:
+        list_index.save_to_disk(str(Path(tmpdir) / "tmp.json"))
+        list_index = cast(
+            GPTListIndex, GPTListIndex.load_from_disk(str(Path(tmpdir) / "tmp.json"))
+        )
+        response = list_index.query(
+            query_str, mode="recursive", query_configs=query_configs
+        )
+        assert str(response) == ("Test?:This is a test.")
+
 
 @patch.object(TokenTextSplitter, "split_text", side_effect=mock_token_splitter_newline)
 @patch.object(LLMPredictor, "predict", side_effect=mock_llmpredictor_predict)
@@ -261,6 +274,16 @@ def test_recursive_query_list_table(
     response = table.query(query_str, mode="recursive", query_configs=query_configs)
     assert str(response) == ("Cat?:This is another test.")
 
+    # test serialize and then back
+    with TemporaryDirectory() as tmpdir:
+        table.save_to_disk(str(Path(tmpdir) / "tmp.json"))
+        table = cast(
+            GPTSimpleKeywordTableIndex,
+            GPTSimpleKeywordTableIndex.load_from_disk(str(Path(tmpdir) / "tmp.json")),
+        )
+        response = table.query(query_str, mode="recursive", query_configs=query_configs)
+        assert str(response) == ("Cat?:This is another test.")
+
 
 @patch.object(LLMChain, "predict", side_effect=mock_llmchain_predict)
 @patch("gpt_index.langchain_helpers.chain_wrapper.OpenAI")
